package com.ruoyi.rocketmq.service;

import java.util.List;
import com.ruoyi.rocketmq.domain.RmTemplateLinux;

/**
 * Linux系统监控项Service接口
 * 
 * @author gyt
 * @date 2025-09-09
 */
public interface IRmTemplateLinuxService 
{
    /**
     * 查询Linux系统监控项
     * 
     * @param id Linux系统监控项主键
     * @return Linux系统监控项
     */
    public RmTemplateLinux selectRmTemplateLinuxById(Long id);

    /**
     * 查询Linux系统监控项列表
     * 
     * @param rmTemplateLinux Linux系统监控项
     * @return Linux系统监控项集合
     */
    public List<RmTemplateLinux> selectRmTemplateLinuxList(RmTemplateLinux rmTemplateLinux);

    /**
     * 新增Linux系统监控项
     * 
     * @param rmTemplateLinux Linux系统监控项
     * @return 结果
     */
    public int insertRmTemplateLinux(RmTemplateLinux rmTemplateLinux);

    /**
     * 修改Linux系统监控项
     * 
     * @param rmTemplateLinux Linux系统监控项
     * @return 结果
     */
    public int updateRmTemplateLinux(RmTemplateLinux rmTemplateLinux);

    /**
     * 批量删除Linux系统监控项
     * 
     * @param ids 需要删除的Linux系统监控项主键集合
     * @return 结果
     */
    public int deleteRmTemplateLinuxByIds(Long[] ids);

    /**
     * 删除Linux系统监控项信息
     * 
     * @param id Linux系统监控项主键
     * @return 结果
     */
    public int deleteRmTemplateLinuxById(Long id);
}
