package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.RmTemplateLinux;
import com.ruoyi.rocketmq.service.IRmTemplateLinuxService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * Linux系统监控项Controller
 * 
 * @author gyt
 * @date 2025-09-09
 */
@RestController
@RequestMapping("/linux")
public class RmTemplateLinuxController extends BaseController
{
    @Autowired
    private IRmTemplateLinuxService rmTemplateLinuxService;

    /**
     * 查询Linux系统监控项列表
     */
    @RequiresPermissions("rocketmq:linux:list")
    @GetMapping("/list")
    public TableDataInfo list(RmTemplateLinux rmTemplateLinux)
    {
        startPage();
        List<RmTemplateLinux> list = rmTemplateLinuxService.selectRmTemplateLinuxList(rmTemplateLinux);
        return getDataTable(list);
    }

    /**
     * 导出Linux系统监控项列表
     */
    @RequiresPermissions("rocketmq:linux:export")
    @Log(title = "Linux系统监控项", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmTemplateLinux rmTemplateLinux)
    {
        List<RmTemplateLinux> list = rmTemplateLinuxService.selectRmTemplateLinuxList(rmTemplateLinux);
        ExcelUtil<RmTemplateLinux> util = new ExcelUtil<RmTemplateLinux>(RmTemplateLinux.class);
        util.exportExcel(response, list, "Linux系统监控项数据");
    }

    /**
     * 获取Linux系统监控项详细信息
     */
    @RequiresPermissions("rocketmq:linux:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmTemplateLinuxService.selectRmTemplateLinuxById(id));
    }

    /**
     * 新增Linux系统监控项
     */
    @RequiresPermissions("rocketmq:linux:add")
    @Log(title = "Linux系统监控项", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmTemplateLinux rmTemplateLinux)
    {
        return toAjax(rmTemplateLinuxService.insertRmTemplateLinux(rmTemplateLinux));
    }

    /**
     * 修改Linux系统监控项
     */
    @RequiresPermissions("rocketmq:linux:edit")
    @Log(title = "Linux系统监控项", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmTemplateLinux rmTemplateLinux)
    {
        return toAjax(rmTemplateLinuxService.updateRmTemplateLinux(rmTemplateLinux));
    }

    /**
     * 删除Linux系统监控项
     */
    @RequiresPermissions("rocketmq:linux:remove")
    @Log(title = "Linux系统监控项", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmTemplateLinuxService.deleteRmTemplateLinuxByIds(ids));
    }
}
